%global gem_name puma
%bcond_with ragel
Name:                rubygem-%{gem_name}
Version:             5.5.2
Release:             1
Summary:             A simple, fast, threaded, and highly concurrent HTTP 1.1 server
License:             BSD-3-Clause
URL:                 http://puma.io
Source0:             https://rubygems.org/gems/%{gem_name}-%{version}.gem
Source1:             https://github.com/puma/%{gem_name}/archive/refs/tags/v%{version}.tar.gz
# Set the default cipher list "PROFILE=SYSTEM".
# https://fedoraproject.org/wiki/Packaging:CryptoPolicies
Patch0:              rubygem-puma-3.6.0-crypto-policy-cipher-list.patch
Patch1:              Support-for-cert_pem-and-key_pem-with-ssl_bind-DSL.patch

BuildRequires:       openssl-devel ruby(release) rubygems-devel ruby-devel rubygem(rack)
BuildRequires:       rubygem(minitest) rubygem(sd_notify)
BuildRequires: 	     rubygem(nio4r)
%if %{with ragel}
BuildRequires:       %{_bindir}/ragel
%endif
BuildRequires:       gcc
%description
A simple, fast, threaded, and highly concurrent HTTP 1.1 server for
Ruby/Rack applications.

%package doc
Summary:             Documentation for %{name}
Requires:            %{name} = %{version}-%{release}
BuildArch:           noarch
%description doc
Documentation for %{name}.

%prep
%setup -q -n  %{gem_name}-%{version} -b 1
%patch0 -p1
%patch1 -p1

%if %{with ragel}
rm -f ext/puma_http11/http11_parser.c
ragel ext/puma_http11/http11_parser.rl -C -G2 -I ext/puma_http11 \
  -o ext/puma_http11/http11_parser.c
%endif

%build
gem build ../%{gem_name}-%{version}.gemspec
%gem_install

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/
mkdir -p %{buildroot}%{gem_extdir_mri}/puma
cp -a .%{gem_extdir_mri}/gem.build_complete %{buildroot}%{gem_extdir_mri}/
cp -a .%{gem_extdir_mri}/puma/*.so %{buildroot}%{gem_extdir_mri}/puma
rm -rf %{buildroot}%{gem_instdir}/ext/
mkdir -p %{buildroot}%{_bindir}
cp -a .%{_bindir}/* \
        %{buildroot}%{_bindir}/
find %{buildroot}%{gem_instdir}/bin -type f | xargs chmod a+x
find %{buildroot}%{gem_instdir}/bin -type f | \
  xargs sed -i 's|^#!/usr/bin/env ruby$|#!/usr/bin/ruby|'

%check
pushd .%{gem_instdir}
ln -s %{_builddir}/%{gem_name}-%{version}/test test
ln -s %{_builddir}/%{gem_name}-%{version}/examples examples

sed -i -e "/require..minitest\/\(retry\|proveit\)./ s/^/#/" test/helper.rb
sed -i "/Minitest::Retry/ s/^/#/" test/helper.rb
sed -i '/prove_it!/ s/^/#/' test/helper.rb
sed -i "/minitest\/stub_const/ s/^/#/" test/helper.rb
sed -i '/::Timeout.timeout/ s/45/300/' test/helper.rb

mv test/test_preserve_bundler_env.rb{,.disable}
mv test/test_thread_pool.rb{,.disable}
mv test/test_worker_gem_independence.rb{,.disable}
sed -i -e '/^\s*def test_prune_bundler_with_multiple_workers$/a\
    skip' \
       -e '/^\s*def test_phased_restart_cluster$/a\
    skip' test/test_integration_pumactl.rb

mv test/test_puma_localhost_authority.rb{,.disable}
mv test/test_integration_single.rb{,.disable}
mv test/test_integration_cluster.rb{,.disable}

%ifarch aarch64
sed -i '/^  def test_control$/,/^  end$/ s/^/#/' test/test_cli.rb
%endif

sed -i '/^  def test_timeout_in_data_phase$/a\
    skip' test/test_puma_server.rb
sed -i '/^  def test_plugin$/a\
    skip' test/test_plugin.rb
sed -i '/^  def test_verify_fail_if_client_unknown_ca$/a\
    skip' test/test_puma_server_ssl.rb

RUBYOPT="-Ilib:$(dirs +1 -l)%{gem_extdir_mri}" \
CI=1 \
LC_ALL=C.UTF-8 \
ruby -e 'Dir.glob "./test/**/test_*.rb", &method(:require)'

%files
%dir %{gem_instdir}
%{_bindir}/puma
%{_bindir}/pumactl
%{gem_extdir_mri}
%license %{gem_instdir}/LICENSE
%{gem_instdir}/bin
%{gem_libdir}
%exclude %{gem_cache}
%{gem_spec}

%files doc
%doc %{gem_docdir}
%doc %{gem_instdir}/History.md
%doc %{gem_instdir}/README.md
%doc %{gem_instdir}/docs
%{gem_instdir}/tools

%changelog
* Tue Nov 1 2022 cadongxia <caodongxia@h-partners.com> - 5.5.2-1
- Upgrade to 5.5.2

* Mon May 31 2021 wangyue <wangyue92@huawei.com>  - 3.12.6-2
- Fix CVE-2021-29509

* Wed Feb 03 2021 shinwell_hu <micromotive@qq.com> - 3.12.6-1
- Upgrade to 3.12.6 to fix following known CVEs
  CVE-2020-11077
  CVE-2020-11076
- Workaround test failure on x forwarded protol

* Thu Aug 20 2020 luoshengwei <luoshengwei@huawei.com> - 3.12.4-1
- package init
